@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: tasty
 version: 0.11.0.2
-id: tasty-0.11.0.2-6ecf5c4c4584053c63756484aea2d9b8
-key: tasty_JSYm4uWxjRl3xRla4ZuZwZ
+id: tasty-0.11.0.2-59915c063df51d2eaf213c92cd2c46a4
+key: tasty_1j2fMTQGeOpBDfE72KtF9X
 license: MIT
 maintainer: Roman Cheplyaka <roma@ro-che.info>
 homepage: http://documentup.com/feuerbach/tasty
@@ -31,12 +31,12 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/tasty-0.11.0.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/tasty-0.11.0.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/tasty-0.11.0.2
-hs-libraries: HStasty-0.11.0.2-JSYm4uWxjRl3xRla4ZuZwZ
+hs-libraries: HStasty-0.11.0.2-1j2fMTQGeOpBDfE72KtF9X
 depends:
     ansi-terminal-0.6.2.3-7b40b18f4e53e6f53c2ffd807e929ca9
     async-2.1.0-b35f12010d11213b63d33c4f0cc6089c
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    clock-0.6.0.1-713f6913c58d4b0a7d37f9b31c87f350
+    clock-0.7.1.1-48205698dc759abc70fe01a1aa47cc9f
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
